@@ -119,7 +119,7 @@ olink_ttest <- function(df, variable, pair_id, ...){
 
   #Every sample needs to have a unique level of the factor
   number_of_samples_w_more_than_one_level <- df %>%
-    dplyr::group_by(SampleID, Index) %>%
+    dplyr::group_by(SampleID) %>%
     dplyr::summarise(n_levels = dplyr::n_distinct(!!rlang::ensym(variable), na.rm = TRUE)) %>%
     dplyr::ungroup() %>%
     dplyr::filter(n_levels > 1) %>%
