@@ -1,7 +1,10 @@
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
-collapse = TRUE,
-comment = "#>")
+  fig.width = 6,
+  fig.height = 3,
+  fig.align = "center",
+  collapse = TRUE,
+  comment = "#>")
 options(tibble.print_min = 4L, tibble.print_max = 4L)
 
 ## ---- eval=FALSE--------------------------------------------------------------
@@ -105,11 +108,15 @@ library(stringr)
 #  # One-way Friedman Test
 #  friedman_results <- olink_one_non_parametric(df = npx_df,
 #                                               variable = "Time",
+#                                               subject = "Subject",
 #                                               dependence = TRUE)
 
 ## ----message=FALSE, eval=FALSE------------------------------------------------
 #  #Friedman Test
-#  Friedman_results <- olink_one_non_parametric(npx_df, "Time", dependence = TRUE)
+#  Friedman_results <- olink_one_non_parametric(df = npx_data1,
+#                                               variable = "Time",
+#                                               subject = "Subject",
+#                                               dependence = TRUE)
 #  
 #  #Filtering out significant and relevant results.
 #  significant_assays <- Friedman_results %>%
@@ -119,14 +126,17 @@ library(stringr)
 #    pull()
 #  
 #  #Posthoc test for the results from Friedman Test
-#  friedman_posthoc_results <- olink_one_non_parametric_posthoc(npx_df, variable = c("Time"), olinkid_list = significant_assays)
+#  friedman_posthoc_results <- olink_one_non_parametric_posthoc(npx_data1,
+#                                                               variable = "Time",
+#                                                               test = "friedman",
+#                                                               olinkid_list = significant_assays)
 
 ## ----message=FALSE, eval=FALSE------------------------------------------------
 #  # Two-way ordinal regression, no covariates
 #  ordinalRegression_results_twoway <- olink_ordinalRegression(df = npx_data1,
 #                                                              variable = c('Site', 'Time'))
 #  # One-way ordinal regression, Treatment as covariates
-#  ordinalRegression_oneway <- olink_anova(df = npx_data1,
+#  ordinalRegression_oneway <- olink_ordinalRegression(df = npx_data1,
 #                                          variable = 'Site',
 #                                          covariates = 'Treatment')
 
@@ -188,7 +198,29 @@ ora_results <- olink_pathway_enrichment(
   test_results = ttest_results, method = "ORA")
 }, silent = TRUE)
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
+npx_data1 %>% 
+  filter(!str_detect(SampleID, 'CONTROL_SAMPLE')) %>% 
+  olink_pca_plot(df = .,
+                 color_g = "QC_Warning", byPanel = TRUE)  
+
+## ----message = FALSE----------------------------------------------------------
+npx_data <- npx_data1 %>%
+    mutate(SampleID = paste(SampleID, "_", Index, sep = ""))
+g <- olink_pca_plot(df=npx_data, color_g = "QC_Warning",
+                    outlierDefX = 2.5, outlierDefY = 4, byPanel = TRUE, quiet = TRUE)
+lapply(g, function(x){x$data}) %>%
+  bind_rows() %>%
+  filter(Outlier == 1) %>% 
+  select(SampleID, Outlier, Panel)
+
+## ----message=FALSE------------------------------------------------------------
+npx_data1 %>% 
+  filter(!str_detect(SampleID, 'CONTROL_SAMPLE')) %>% 
+  olink_umap_plot(df = .,
+                 color_g = "QC_Warning", byPanel = TRUE)  
+
+## ----message=FALSE------------------------------------------------------------
 plot <- npx_data1 %>%
   na.omit() %>% # removing missing values which exists for Site
   olink_boxplot(variable = "Site", 
@@ -211,13 +243,13 @@ plot2 <- npx_data1 %>%
 plot2[[1]]
 
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
 npx_data1 %>% 
   filter(Panel == 'Olink Cardiometabolic') %>% # For this example only plotting one panel.
   olink_dist_plot() +
   theme(axis.text.x = element_blank()) # Due to the number of samples one can remove the text or rotate it
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE, fig.width= 8----------------------------------------------
 plot <- olink_lmer_plot(df = npx_data1, 
                         olinkid_list = c("OID01216", "OID01217"), 
                         variable = c('Site', 'Treatment'), 
@@ -226,36 +258,20 @@ plot <- olink_lmer_plot(df = npx_data1,
                         random = 'Subject')
 plot[[1]]
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
-npx_data1 %>% 
-  filter(!str_detect(SampleID, 'CONTROL_SAMPLE')) %>% 
-  olink_pca_plot(df = .,
-                 color_g = "QC_Warning", byPanel = TRUE)  
-
-## ----message = FALSE----------------------------------------------------------
-npx_data <- npx_data1 %>%
-    mutate(SampleID = paste(SampleID, "_", Index, sep = ""))
-g <- olink_pca_plot(df=npx_data, color_g = "QC_Warning",
-                    outlierDefX = 2.5, outlierDefY = 4, byPanel = TRUE, quiet = TRUE)
-lapply(g, function(x){x$data}) %>%
-  bind_rows() %>%
-  filter(Outlier == 1) %>% 
-  select(SampleID, Outlier, Panel)
-
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE, fig.height=4, fig.width=8---------------------------------
 # GSEA Heatmap from t-test results
 try({ # This expression might fail if dependencies are not installed
 olink_pathway_heatmap(enrich_results = gsea_results, test_results = ttest_results)
 })
 
-## ----message = FALSE, fig.width=8, fig.height=4-------------------------------
+## ----message = FALSE, fig.height=4, fig.width=8-------------------------------
 # ORA Heatmap from t-test results with cell keyword
 try({ # This expression might fail if dependencies are not installed
 olink_pathway_heatmap(enrich_results = ora_results, test_results = ttest_results,
                       method = "ORA", keyword = "cell")
 })
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
 npx_data1 %>% 
   filter(!str_detect(SampleID, 'CONTROL_SAMPLE'),
          Panel == 'Olink Inflammation') %>% 
@@ -265,7 +281,7 @@ npx_data1 %>%
 qc <- olink_qc_plot(npx_data1, color_g = "QC_Warning", IQR_outlierDef = 3, median_outlierDef = 3)
 qc$data %>% filter(Outlier == 1) %>% select(SampleID, Panel, IQR, sample_median, Outlier)
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE, fig.height=4----------------------------------------------
 first10 <- npx_data1 %>%
   pull(OlinkID) %>% 
   unique() %>% 
@@ -282,7 +298,7 @@ npx_data_small <- npx_data1 %>%
 
 olink_heatmap_plot(npx_data_small, variable_row_list =  'Treatment')
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
 # perform t-test
 ttest_results <- olink_ttest(df = npx_data1,
                              variable = 'Treatment')
@@ -295,14 +311,14 @@ olink_volcano_plot(p.val_tbl = ttest_results,
                    x_lab = 'Treatment',
                    olinkid_list = top_10_name)
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
 npx_data1 %>% 
   filter(OlinkID == 'OID01216') %>% 
   ggplot(aes(x = Treatment, y = NPX, fill = Treatment)) +
   geom_boxplot() +
   set_plot_theme()
 
-## ----message=FALSE, fig.width=8, fig.height=4---------------------------------
+## ----message=FALSE------------------------------------------------------------
 npx_data1 %>% 
   filter(OlinkID == 'OID01216') %>% 
   ggplot(aes(x = Treatment, y = NPX, fill = Treatment)) +
